============================
Djblets 0.8.18 Release Notes
============================

**Release date**: March 18, 2015


djblets.webapi
==============

* Fixed a crash that could occur with object serialization.

  Certain types of data associated with a Django model could result in
  a crash when internally storing serialized data. We now avoid this with
  smarter storage behavior.


Contributors
============

* Christian Hammond
